==> artemis_cupps-0.0.83.tar.gz: lib/classes/Requests/print_request.dart <==
import 'package:artemis_cupps/utility/const.dart';
import 'package:xml/xml.dart';

import '../classes.dart';

class PrintRequest extends CuppsBase {
  final List<PrintDocument> printDocuments;

  PrintRequest({
    required int messageID,
    String? xmlns,
    String? xsi,
    required this.printDocuments,
  }) : super(messageID: messageID, messageName: "printRequest");

  factory PrintRequest.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);

    String messageID = document.rootElement.attributes
        .firstWhere((p0) => p0.name.toString() == "messageID")
        .value;
    List<XmlElement> docsElements =
        document.rootElement.findAllElements("printDocument").toList();
    List<PrintDocument> printDocuments = docsElements
        .map((e) => PrintDocument.fromXML(e.toXmlString()))
        .toList();
    // List<XmlElement> textMessages = messageElements.where((element) => element.childElements.any((ee) => ee.name.toString() == "aeaText")).toList();
    // List<XmlElement> pdfs = messageElements.where((element) => element.childElements.any((ee) => ee.name.toString() == "aeaBinary")).toList();

    return PrintRequest(
        printDocuments: printDocuments, messageID: int.parse(messageID));
  }

  @override
  String toXML() {
    return '''<?xml version="1.0" encoding="utf-8"?><cupps xmlns="$xmlns" messageID="$messageID" xmlns:xsi="#$xsi" messageName="$messageName">
<printRequest>
${printDocuments.map((e) => e.toXML()).join()}
</printRequest>
</cupps>'''
        .replaceAll(" ", artemisWhiteSpace)
        .replaceAll("*^*ENTER*^*", artemisWhiteEnter);
  }

  @override
  String toString() {
    return "$messageID : $messageName ";
  }
}

class PrintDocument {
  final String documentID;
  final String stockName;
  final List<String> pdfs;
  final List<DocumentNode> textDocuments;

  PrintDocument(
      {required this.pdfs,
      required this.textDocuments,
      required this.documentID,
      required this.stockName});

  factory PrintDocument.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    List<XmlElement> pdfElements =
        document.findAllElements("pdfPrintDocument").toList();
    List<XmlElement> textElements =
        document.findAllElements("simpleTextPrintDocumentTextNode").toList();
    String documentID = document.rootElement.attributes
        .firstWhere((p0) => p0.name.toString() == "documentID")
        .value;
    String stockName = document.rootElement.attributes
        .firstWhere((p0) => p0.name.toString() == "stockName")
        .value;

    List<String> pdfs = pdfElements.map((e) => e.text).toList();
    List<DocumentNode> texts =
        textElements.map((e) => DocumentNode.fromXML(e.toXmlString())).toList();
    // List<TextNode> texts = nodesElements.map((e) => TextNode.fromXML(e.toXmlString())).toList();
    return PrintDocument(
        pdfs: pdfs,
        textDocuments: texts,
        documentID: documentID,
        stockName: stockName);
  }

  String toXML() {
    return '''<printDocument documentID="$documentID" stockName="$stockName">
${pdfs.map((e) => e).join()}
<simpleTextPrintDocument>
${textDocuments.map((e) => e.toXML()).join()}
</simpleTextPrintDocument>
</printDocument>
''';
  }
}

class DocumentNode {
  final List<TextNode> texts;

  DocumentNode({required this.texts});

  factory DocumentNode.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    List<XmlElement> nodesElements =
        document.findAllElements("simpleTextPrintDocumentTextNode").toList();
    List<TextNode> texts =
        nodesElements.map((e) => TextNode.fromXML(e.toXmlString())).toList();
    return DocumentNode(texts: texts);
  }

  String toXML() {
    return '''<simpleTextPrintDocumentNode>
${texts.map((e) => e.toXML()).join()}
<simpleTextPrintDocumentBinaryNode />
</simpleTextPrintDocumentNode>
''';
  }
}

class TextNode {
  final String value;

  TextNode({required this.value});

  factory TextNode.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String str = document.firstChild?.text ?? "";
    return TextNode(value: str);
  }

  String toXML() {
    return '''<simpleTextPrintDocumentTextNode>$value</simpleTextPrintDocumentTextNode>'''
        .replaceAll("\n", "*^*ENTER*^*")
        .replaceAll(" ", artemisWhiteSpace)
        .replaceAll("\t", "")
        .replaceAll("", "");
  }

  @override
  String toString() {
    return value;
  }
}

==> artemis_cupps-0.0.90.tar.gz: lib/classes/Requests/print_request.dart <==
import 'package:artemis_cupps/utility/const.dart';
import 'package:xml/xml.dart';

import '../classes.dart';

class PrintRequest extends CuppsBase {
  final List<PrintDocument> printDocuments;

  PrintRequest({
    required int messageID,
    String? xmlns,
    String? xsi,
    required this.printDocuments,
  }) : super(messageID: messageID, messageName: "printRequest");

  factory PrintRequest.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);

    String messageID = document.rootElement.attributes
        .firstWhere((p0) => p0.name.toString() == "messageID")
        .value;
    List<XmlElement> docsElements =
    document.rootElement.findAllElements("printDocument").toList();
    List<PrintDocument> printDocuments = docsElements
        .map((e) => PrintDocument.fromXML(e.toXmlString()))
        .toList();
    // List<XmlElement> textMessages = messageElements.where((element) => element.childElements.any((ee) => ee.name.toString() == "aeaText")).toList();
    // List<XmlElement> pdfs = messageElements.where((element) => element.childElements.any((ee) => ee.name.toString() == "aeaBinary")).toList();

    return PrintRequest(
        printDocuments: printDocuments, messageID: int.parse(messageID));
  }

  @override
  String toXML() {
    return '''<?xml version="1.0" encoding="utf-8"?><cupps xmlns="$xmlns" messageID="$messageID" xmlns:xsi="#$xsi" messageName="$messageName">
<printRequest>
${printDocuments.map((e) => e.toXML()).join()}
</printRequest>
</cupps>'''
        .replaceAll(" ", artemisWhiteSpace)
        .replaceAll("*^*ENTER*^*", artemisWhiteEnter);
  }

  @override
  String toString() {
    return "$messageID : $messageName ";
  }
}

class PrintDocument {
  final String documentID;
  final String stockName;
  final List<String> pdfs;
  final List<DocumentNode> textDocuments;

  PrintDocument(
      {required this.pdfs,
        required this.textDocuments,
        required this.documentID,
        required this.stockName});

  factory PrintDocument.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    List<XmlElement> pdfElements =
    document.findAllElements("pdfPrintDocument").toList();
    List<XmlElement> textElements =
    document.findAllElements("simpleTextPrintDocumentTextNode").toList();
    String documentID = document.rootElement.attributes
        .firstWhere((p0) => p0.name.toString() == "documentID")
        .value;
    String stockName = document.rootElement.attributes
        .firstWhere((p0) => p0.name.toString() == "stockName")
        .value;

    List<String> pdfs = pdfElements.map((e) => e.text).toList();
    List<DocumentNode> texts =
    textElements.map((e) => DocumentNode.fromXML(e.toXmlString())).toList();
    // List<TextNode> texts = nodesElements.map((e) => TextNode.fromXML(e.toXmlString())).toList();
    return PrintDocument(
        pdfs: pdfs,
        textDocuments: texts,
        documentID: documentID,
        stockName: stockName);
  }

  String toXML() {
    return '''<printDocument documentID="$documentID" stockName="$stockName">
${pdfs.map((e) => '''<pdfPrintDocument>$e</pdfPrintDocument>\n''').join()}
<simpleTextPrintDocument>
${textDocuments.map((e) => e.toXML()).join()}
</simpleTextPrintDocument>
</printDocument>
''';
  }
}

class DocumentNode {
  final List<TextNode> texts;

  DocumentNode({required this.texts});

  factory DocumentNode.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    List<XmlElement> nodesElements =
    document.findAllElements("simpleTextPrintDocumentTextNode").toList();
    List<TextNode> texts =
    nodesElements.map((e) => TextNode.fromXML(e.toXmlString())).toList();
    return DocumentNode(texts: texts);
  }

  String toXML() {
    return '''<simpleTextPrintDocumentNode>
${texts.map((e) => e.toXML()).join()}
<simpleTextPrintDocumentBinaryNode />
</simpleTextPrintDocumentNode>
''';
  }
}

class TextNode {
  final String value;

  TextNode({required this.value});

  factory TextNode.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String str = document.firstChild?.text ?? "";
    return TextNode(value: str);
  }

  String toXML() {
    return '''<simpleTextPrintDocumentTextNode>$value</simpleTextPrintDocumentTextNode>'''
        .replaceAll("\n", "*^*ENTER*^*")
        .replaceAll(" ", artemisWhiteSpace)
        .replaceAll("\t", "")
        .replaceAll("", "");
  }

  @override
  String toString() {
    return value;
  }
}
